@@ -71,6 +71,9 @@ class RootNodeCallback:
                     return
                 
                 parent = child.parent()
+                if not parent:
+                    return 
+
                 children = parent.get_children()
                 index = 0
                 for child_node in children:
@@ -104,7 +107,7 @@ class RootNodeCallback:
                 for child_node in child.get_children():
                     self.add_exist_child(item, child, child_node)
             
-            def remove_child(self, event, node, child):
+            def remove_child(self, event, node, child, index):
                 if node != self._node:
                     return
 
@@ -452,6 +455,10 @@ class DataExploreExtension:
         global _frame
         _frame = frame
 
+def OnNodeDelete(event, node):
+    global _dataexplore_view
+    _dataexplore_view.treeWidget.selectionChanged(0,0)
+
 class ActionNewNode:
     def __init__(self, kind, parent = None):
         self._kind = kind
@@ -528,7 +535,7 @@ class DataExploreBasicOpMenu:
         self.menus = []
 
         if len(nodes) == 0:
-            obj = ActionNewNode("")
+            obj = ActionNewNode("", nodes)
             action = menu.addAction("新建根节点2")
             action.triggered.connect(obj.on_new_node)
             self.menus.append(obj)
@@ -802,6 +809,10 @@ config = {
         {
             "name": 'event::NewRootDataNode',
             "define": OnRootNodeNew
+        },
+        {
+            "name": 'event::DataNode::Delete', 
+            "define": OnNodeDelete
         }
     ]
 }
\ No newline at end of file
